==> dde-shell_1.99.36.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Estilo do indicador</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Eficiente</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Modo clássico</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Modo centralizado</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Exibição</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Sempre exibir</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Sempre ocultar</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultar automaticamente</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Configurações do dock</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Estilo do indicador</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Fashion</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Eficiente</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Clássico</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Centralizado</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Inferior</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Exibição</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Sempre exibir</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Sempre ocultar</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Ocultar automaticamente</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Configurações do dock</translation>
    </message>
</context>
</TS>
